#!/usr/bin/perl

use v5.10;
use Cwd;
use Getopt::Std;
use File::Glob ':bsd_glob';
use File::Basename;

sub debug {
    return unless $opt_d;
    say 'debug: ', @_;
}

getopts("dv");

die "usage: $0 [-dv] titlesfile"  if @ARGV != 1;

($file,$dir,undef)  = fileparse($ARGV[0]);

$origdir = getcwd();

chdir $dir or die "$!: $dir";

@files = bsd_glob("$base*.\{mp3\}");

if (! @files) {
    say "No mp3 music files in directory";
}

for (@files) {
    if (/^(.*) - (\d+)\..+$/) {
	$tracks[$2] = $_;
	debug "found file $2: $_";
    }
    else {
	debug "skipping file: $_";
    }
};

unless (@tracks) {
    say "No tracks to process";
    chdir $origdir or die "Cannot return to original directory: $!"; 
    exit 1;
}

open(TITLESFILE, "<", $file) or
    die "Can't open title file $file in $dir: $!\n";

while (<TITLESFILE>) {
    chomp;
    next if /^$/;
    if (($n) = /^(\d+)/) {
	debug "track $n: MATCH: '$_' ==> '$tracks[$n]'"  if $tracks[$n];
	($suffix) = ($tracks[$n] =~ /(\..+)$/);
	say "rename $tracks[$n], $_$suffix"	if $opt_v || $opt_d;
	rename $tracks[$n], $_ . $suffix	unless $opt_d;
    }
    else {
	debug "unmatched: $1: $_";
	debug "Track $1: NO MATCH: '$_'"  if $tracks[$1];
    }
}

chdir $origdir or die "Cannot return to original directory: $!"; 
close TITLESFILE;
exit 1;
